    {% macro menu() %}
    <ul>
    {% for dirname in sorted(navigation.directories[1]) -%}
    {% set subdirs = navigation.directories[1][dirname] -%}

    {% if navigation.current_index == dirname -%}
    {% set liclass = 'active' -%}
    {% else -%}
    {% set liclass = '' -%}
    {% endif -%}

    <li class="{{ liclass }}"><a href="/{{ dirname }}">{{ dirname.capitalize() }}</a></li>
    {% endfor -%}

    {% endmacro %}